@@ -24,17 +24,15 @@
 #include <config.h>
 #include "gnome-vfs-configuration.h"
 
-#include <dirent.h>
 #include <errno.h>
-#include <glib/ghash.h>
-#include <glib/glist.h>
-#include <glib/gmem.h>
-#include <glib/gmessages.h>
-#include <glib/gstrfuncs.h>
-#include <glib/gthread.h>
-#include <glib/gutils.h>
-#include "gnome-vfs-i18n.h"
+#include <glib.h>
+#include <glib/gstdio.h>
+#include <glib/gi18n-lib.h>
 #include "gnome-vfs-private.h"
+#ifdef G_OS_WIN32
+#include "gnome-vfs-private-utils.h"
+#endif
+
 #include <sys/stat.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -363,7 +361,7 @@ parse_file (Configuration *configuration,
 	guint line_buffer_size;
 	guint line_number;
 
-	f = fopen (file_name, "r");
+	f = g_fopen (file_name, "r");
 	if (f == NULL) {
 		g_warning (_("Configuration file `%s' was not found: %s"),
 			   file_name, strerror (errno));
@@ -399,31 +397,31 @@ configuration_load (void)
 	gchar *file_names[MAX_CFG_FILES + 1];
 	GList *list;
 	int i = 0;
-	DIR *dirh;
+	GDir *dirh;
 
 	configuration->method_to_module_path = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, hash_free_module_path);
 
 	/* Go through the list of configuration directories and build up a list of config files */
 	for (list = configuration->directories; list && i < MAX_CFG_FILES; list = list->next) {
 		VfsDirSource *dir_source = (VfsDirSource *)list->data;
-		struct dirent *dent;
+		const char *dent;
 
-		if (stat (dir_source->dirname, &dir_source->s) == -1)
+		if (g_stat (dir_source->dirname, &dir_source->s) == -1)
 			continue;
 
-		dirh = opendir (dir_source->dirname);
+		dirh = g_dir_open (dir_source->dirname, 0, NULL);
 		if(!dirh)
 			continue;
 
-		while ((dent = readdir(dirh)) && i < MAX_CFG_FILES) {
+		while ((dent = g_dir_read_name(dirh)) && i < MAX_CFG_FILES) {
 			char *ctmp;
-			ctmp = strstr(dent->d_name, ".conf");
+			ctmp = strstr(dent, ".conf");
 			if(!ctmp || strcmp(ctmp, ".conf"))
 				continue;
-			file_names[i] = g_strdup_printf ("%s/%s", dir_source->dirname, dent->d_name);
+			file_names[i] = g_build_filename (dir_source->dirname, dent, NULL);
 			i++;
 		}
-		closedir(dirh);
+		g_dir_close(dirh);
 	}
 	file_names[i] = NULL;
 
@@ -469,7 +467,7 @@ install_path_list (const gchar *environment_path)
 	while (1) {
 		char *elem;
 
-		p = strchr (oldp, ':');
+		p = strchr (oldp, G_SEARCHPATH_SEPARATOR);
 
 		if (p == NULL) {
 			if (*oldp != '\0') {
@@ -493,6 +491,7 @@ _gnome_vfs_configuration_init (void)
 	char *home_config;
 	char *environment_path;
 	const char *home_dir;
+	char *cfgdir;
 
 	G_LOCK (configuration);
 	if (configuration != NULL) {
@@ -502,7 +501,9 @@ _gnome_vfs_configuration_init (void)
 
 	configuration = g_new0 (Configuration, 1);
 
-	add_directory_internal (GNOME_VFS_MODULE_CFGDIR);
+	cfgdir = g_build_filename (GNOME_VFS_SYSCONFDIR, GNOME_VFS_MODULE_SUBDIR, NULL);
+	add_directory_internal (cfgdir);
+	g_free (cfgdir);
 	environment_path = getenv ("GNOME_VFS_MODULE_CONFIG_PATH");
 	if (environment_path != NULL) {
 		install_path_list (environment_path);
@@ -510,10 +511,9 @@ _gnome_vfs_configuration_init (void)
 
 	home_dir = g_get_home_dir ();
 	if (home_dir != NULL) {
-		home_config = g_strdup_printf ("%s%c%s",
-					       home_dir,
-					       G_DIR_SEPARATOR,
-					       ".gnome2/vfs/modules");
+		home_config = g_build_filename (home_dir,
+						".gnome2", "vfs", "modules",
+						NULL);
 		add_directory_internal (home_config);
 		g_free (home_config);
 	}
@@ -557,7 +557,7 @@ maybe_reload (void)
 
 	for (list = configuration->directories; list; list = list->next) {
 		VfsDirSource *dir_source = (VfsDirSource *) list->data;
-		if (stat (dir_source->dirname, &s) == -1)
+		if (g_stat (dir_source->dirname, &s) == -1)
 			continue;
 		if (s.st_mtime != dir_source->s.st_mtime) {
 			need_reload = TRUE;
