@@ -26,7 +26,9 @@
 #include <string.h>
 #include <sys/stat.h>
 #include <sys/time.h>
+#include <time.h>
 #include <glib.h>
+#include <glib/gstdio.h>
 #include "gnome-vfs-mime.h"
 #include "gnome-vfs-mime-info-cache.h"
 #include "gnome-vfs-mime-info.h"
@@ -98,7 +100,7 @@ gnome_vfs_mime_info_cache_dir_out_of_date (GnomeVFSMimeInfoCacheDir *dir, const
 
 	filename = g_build_filename (dir->path, cache_file, NULL);
 
-	if (stat (filename, &buf) < 0) {
+	if (g_stat (filename, &buf) < 0) {
 		g_free (filename);
 		return TRUE;
 	}
@@ -156,7 +158,7 @@ gnome_vfs_mime_info_cache_dir_init (GnomeVFSMimeInfoCacheDir *dir)
 
 	filename = g_build_filename (dir->path, "mimeinfo.cache", NULL);
 
-	if (stat (filename, &buf) < 0)
+	if (g_stat (filename, &buf) < 0)
 		goto error;
 
 	if (dir->mime_info_cache_timestamp > 0) 
@@ -246,7 +248,7 @@ gnome_vfs_mime_info_cache_dir_init_defaults_list (GnomeVFSMimeInfoCacheDir *dir)
 
 	filename = g_build_filename (dir->path, "defaults.list", NULL);
 
-	if (stat (filename, &buf) < 0)
+	if (g_stat (filename, &buf) < 0)
 		goto error;
 
 	if (dir->defaults_list_timestamp > 0) 
@@ -607,13 +609,13 @@ _gnome_vfs_mime_info_cache_init (void)
 	if (mime_info_cache == NULL) {
 		gnome_vfs_mime_info_cache_init_dir_lists ();
 	} else {
-		struct timeval tv;
+		time_t now;
 
-		gettimeofday (&tv, NULL);
+		time (&now);
 
-		if (tv.tv_sec >= mime_info_cache->last_stat_time + 5) {
+		if (now >= mime_info_cache->last_stat_time + 5) {
 			gnome_vfs_mime_info_cache_update_dir_lists ();
-			mime_info_cache->last_stat_time = tv.tv_sec;
+			mime_info_cache->last_stat_time = now;
 		}
 	}
 
@@ -652,6 +654,12 @@ gnome_vfs_mime_info_cache_free (GnomeVFSMimeInfoCache *cache)
 	g_free (cache);
 }
 
+/**
+ * gnome_vfs_mime_info_cache_reload:
+ * @dir: directory path which needs reloading.
+ * 
+ * Reload the mime information for the @dir.
+ */
 void
 gnome_vfs_mime_info_cache_reload (const char *dir)
 {
@@ -686,6 +694,16 @@ get_all_parent_types (const char *mime_type)
 	return g_list_reverse (l);
 }
 
+/**
+ * gnome_vfs_mime_get_all_desktop_entries:
+ * @mime_type: a mime type.
+ *
+ * Returns all the desktop filenames for @mime_type.
+ *
+ * Return value: a #GList containing the desktop filenames containing the
+ * @mime_type.
+ */
+
 GList *
 gnome_vfs_mime_get_all_desktop_entries (const char *mime_type)
 {
@@ -792,6 +810,14 @@ get_default_desktop_entry (const char *mime_type)
 	return NULL;
 }
 
+/**
+ * gnome_vfs_mime_get_default_desktop_entry:
+ * @mime_type: a mime type.
+ *
+ * Returns the default desktop filename for @mime_type.
+ *
+ * Return value: the default desktop filename for @mime_type.
+ */
 gchar *
 gnome_vfs_mime_get_default_desktop_entry (const char *mime_type)
 {
