@@ -1,7 +1,6 @@
 #include <config.h>
 
 #include "gnome-vfs-module-shared.h"
-#include <dirent.h>
 #include <errno.h>
 #include <fcntl.h>
 #include <limits.h>
@@ -14,14 +13,14 @@
 
 /**
  * gnome_vfs_mime_type_from_mode:
- * @mode:
+ * @mode: value as the st_mode field in the system stat structure.
  *
- * Returns a MIME type based on the mode passed. It only works when mode
- * references a special file (directory, device, fifo, socket or symlink)
+ * Returns a MIME type based on the @mode. It only works when @mode
+ * references a special file (directory, device, fifo, socket or symlink).
  *
  * Returns: a string containing the MIME type, if @mode is a normal file
- * returns NULL.
- **/
+ * returns %NULL.
+ */
 
 const gchar *
 gnome_vfs_mime_type_from_mode (mode_t mode)
@@ -38,10 +37,14 @@ gnome_vfs_mime_type_from_mode (mode_t mode)
 		mime_type = "x-special/device-block";
 	else if (S_ISFIFO (mode))
 		mime_type = "x-special/fifo";
+#ifdef S_ISLNK
 	else if (S_ISLNK (mode))
 		mime_type = "x-special/symlink";
+#endif
+#ifdef S_ISSOCK
 	else if (S_ISSOCK (mode))
 		mime_type = "x-special/socket";
+#endif
 	else
 		mime_type = NULL;
 
@@ -50,48 +53,73 @@ gnome_vfs_mime_type_from_mode (mode_t mode)
 
 /**
  * gnome_vfs_get_special_mime_type:
- * @uri:
+ * @uri: a #GnomeVFSURI to get the mime type for.
  *
  * Gets the MIME type for @uri, this function only returns the type
- * when the URI points to a file that can't be sniffed (sockets, 
+ * when the uri points to a file that can't be sniffed (sockets, 
  * directories, devices, and fifos).
  *
- * Returns: a string containing the mime type, NULL if the @uri doesn't 
- * present an special file.
- **/
+ * Returns: a string containing the mime type or %NULL if the @uri doesn't 
+ * present a special file.
+ */
 
 const char *
 gnome_vfs_get_special_mime_type (GnomeVFSURI *uri)
 {
 	GnomeVFSResult error;
-	GnomeVFSFileInfo info;
-
+	GnomeVFSFileInfo *info;
+	const char *type;
+	
+	info = gnome_vfs_file_info_new ();
+	type = NULL;
+	
 	/* Get file info and examine the type field to see if file is 
 	 * one of the special kinds. 
 	 */
-	error = gnome_vfs_get_file_info_uri (uri, &info, GNOME_VFS_FILE_INFO_DEFAULT);
-	if (error != GNOME_VFS_OK) {
-		return NULL;
-	}
+	error = gnome_vfs_get_file_info_uri (uri, info, GNOME_VFS_FILE_INFO_DEFAULT);
 
-	switch (info.type) {
-	case GNOME_VFS_FILE_TYPE_DIRECTORY:
-		return "x-directory/normal";
-	case GNOME_VFS_FILE_TYPE_CHARACTER_DEVICE:
-		return "x-special/device-char";
-	case GNOME_VFS_FILE_TYPE_BLOCK_DEVICE:
-		return "x-special/device-block";
-	case GNOME_VFS_FILE_TYPE_FIFO:
-		return "x-special/fifo";
-	case GNOME_VFS_FILE_TYPE_SOCKET:
-		return "x-special/socket";
-	default:
-		break;
-	}
+	if (error == GNOME_VFS_OK && 
+	    info->valid_fields & GNOME_VFS_FILE_INFO_FIELDS_TYPE) {
+		
+		switch (info->type) {
 
-	return NULL;	
+			case GNOME_VFS_FILE_TYPE_DIRECTORY:
+				type = "x-directory/normal";
+				break;
+				
+			case GNOME_VFS_FILE_TYPE_CHARACTER_DEVICE:
+				type = "x-special/device-char";
+				break;
+				
+			case GNOME_VFS_FILE_TYPE_BLOCK_DEVICE:
+				type = "x-special/device-block";
+				break;
+				
+			case GNOME_VFS_FILE_TYPE_FIFO:
+				type = "x-special/fifo";
+				break;
+				
+			case GNOME_VFS_FILE_TYPE_SOCKET:
+				type = "x-special/socket";
+				break;
+
+			default:
+				break;
+		}
+
+	}
+	
+	gnome_vfs_file_info_unref (info);
+	return type;	
 }
 
+/**
+ * gnome_vfs_stat_to_file_info:
+ * @file_info: a #GnomeVFSFileInfo which will be filled.
+ * @statptr: pointer to a 'stat' structure.
+ *
+ * Fills the @file_info structure with the values from @statptr structure.
+ */
 void
 gnome_vfs_stat_to_file_info (GnomeVFSFileInfo *file_info,
 			     const struct stat *statptr)
@@ -104,8 +132,10 @@ gnome_vfs_stat_to_file_info (GnomeVFSFileInfo *file_info,
 		file_info->type = GNOME_VFS_FILE_TYPE_BLOCK_DEVICE;
 	else if (S_ISFIFO (statptr->st_mode))
 		file_info->type = GNOME_VFS_FILE_TYPE_FIFO;
+#ifdef S_ISSOCK
 	else if (S_ISSOCK (statptr->st_mode))
 		file_info->type = GNOME_VFS_FILE_TYPE_SOCKET;
+#endif
 	else if (S_ISREG (statptr->st_mode))
 		file_info->type = GNOME_VFS_FILE_TYPE_REGULAR;
 	else if (S_ISLNK (statptr->st_mode))
@@ -130,8 +160,22 @@ gnome_vfs_stat_to_file_info (GnomeVFSFileInfo *file_info,
 	file_info->gid = statptr->st_gid;
 
 	file_info->size = statptr->st_size;
+#ifndef G_OS_WIN32
 	file_info->block_count = statptr->st_blocks;
 	file_info->io_block_size = statptr->st_blksize;
+	if (file_info->io_block_size > 0 &&
+	    file_info->io_block_size < 4096) {
+		/* Never use smaller block than 4k,
+		   should probably be pagesize.. */
+		file_info->io_block_size = 4096;
+	}
+#else
+	file_info->io_block_size = 512;
+	file_info->block_count =
+	  (file_info->size + file_info->io_block_size - 1) /
+	  file_info->io_block_size;
+#endif
+	
 
 	file_info->atime = statptr->st_atime;
 	file_info->ctime = statptr->st_ctime;
