@@ -79,9 +79,9 @@ enum {
 static gint64
 system_time (void)
 {
-	struct timeval time_of_day;
+	GTimeVal time_of_day;
 
-	gettimeofday (&time_of_day, NULL);
+	g_get_current_time (&time_of_day);
 	return (gint64) time_of_day.tv_usec + ((gint64) time_of_day.tv_sec) * 1000000;
 }
 
@@ -101,6 +101,7 @@ init_progress (GnomeVFSProgressCallbackState *progress_state,
 	progress_info->bytes_copied = 0;
 	progress_info->total_bytes_copied = 0;
 	progress_info->duplicate_name = NULL;
+	progress_info->duplicate_count = 0;
 	progress_info->top_level_item = FALSE;
 
 	progress_state->progress_info = progress_info;
@@ -1511,15 +1512,17 @@ copy_file (GnomeVFSFileInfo *info,
 	if (result == GNOME_VFS_OK) {
 		/* ignore errors while setting file info attributes at this point */
 		
-		/* FIXME the modules should ignore setting of permissions if
-		 * "valid_fields & GNOME_VFS_FILE_INFO_FIELDS_PERMISSIONS" is clear
-		 * for now, make sure permissions aren't set to 000
-		 */
-		if ((info->valid_fields & GNOME_VFS_FILE_INFO_FIELDS_PERMISSIONS) != 0) {
-			/* Call this separately from the time one, since one of them may fail,
-			   making the other not run. */
-			gnome_vfs_set_file_info_uri (target_uri, info, 
-						     GNOME_VFS_SET_FILE_INFO_OWNER | GNOME_VFS_SET_FILE_INFO_PERMISSIONS);
+		if (!(xfer_options & GNOME_VFS_XFER_TARGET_DEFAULT_PERMS)) {
+			/* FIXME the modules should ignore setting of permissions if
+			 * "valid_fields & GNOME_VFS_FILE_INFO_FIELDS_PERMISSIONS" is clear
+			 * for now, make sure permissions aren't set to 000
+			 */
+			if ((info->valid_fields & GNOME_VFS_FILE_INFO_FIELDS_PERMISSIONS) != 0) {
+				/* Call this separately from the time one, since one of them may fail,
+				   making the other not run. */
+				gnome_vfs_set_file_info_uri (target_uri, info, 
+							     GNOME_VFS_SET_FILE_INFO_OWNER | GNOME_VFS_SET_FILE_INFO_PERMISSIONS);
+			}
 		}
 		
 		/* Call this last so nothing else changes the times */
@@ -1629,7 +1632,8 @@ copy_directory (GnomeVFSFileInfo *source_file_info,
 
 				source_uri = gnome_vfs_uri_append_file_name (source_dir_uri, info->name);
 				dest_uri = gnome_vfs_uri_append_file_name (target_dir_uri, info->name);
-				
+				progress_set_source_target_uris (progress, source_uri, dest_uri);
+
 				if (info->type == GNOME_VFS_FILE_TYPE_REGULAR) {
 					result = copy_file (info, source_uri, dest_uri, 
 							    xfer_options, error_mode, overwrite_mode, 
@@ -1681,28 +1685,38 @@ copy_directory (GnomeVFSFileInfo *source_file_info,
 	gnome_vfs_directory_close (dest_directory_handle);
 	gnome_vfs_directory_close (source_directory_handle);
 
-	if (result == GNOME_VFS_OK) {
+	if (result == GNOME_VFS_OK) {			
 		GnomeVFSFileInfo *info;
-		info = gnome_vfs_file_info_new ();
-		/* FIXME the modules should ignore setting of permissions if
-		 * "valid_fields & GNOME_VFS_FILE_INFO_FIELDS_PERMISSIONS" is clear
-		 * for now, make sure permissions aren't set to 000
-		 */
-		gnome_vfs_file_info_copy (source_file_info, info);
-		if (target_dir_info && GNOME_VFS_FILE_INFO_SGID(target_dir_info)) {
+
+		if (target_dir_info && GNOME_VFS_FILE_INFO_SGID (target_dir_info)) {
+			info = gnome_vfs_file_info_dup (source_file_info);
 			info->gid = target_dir_info->gid;
+		} else {
+			/* No need to dup the file info in this case */
+			gnome_vfs_file_info_ref (source_file_info);
+			info = source_file_info;
 		}
-		if ((source_file_info->valid_fields & GNOME_VFS_FILE_INFO_FIELDS_PERMISSIONS) != 0) {
-			/* Call this separately from the time one, since one of them may fail,
-			   making the other not run. */
-			gnome_vfs_set_file_info_uri (target_dir_uri, info, 
-						     GNOME_VFS_SET_FILE_INFO_OWNER | GNOME_VFS_SET_FILE_INFO_PERMISSIONS);
+
+		if (!(xfer_options & GNOME_VFS_XFER_TARGET_DEFAULT_PERMS)) {
+			/* FIXME the modules should ignore setting of permissions if
+			 * "valid_fields & GNOME_VFS_FILE_INFO_FIELDS_PERMISSIONS" is clear
+			 * for now, make sure permissions aren't set to 000
+			 */
+			if ((info->valid_fields & GNOME_VFS_FILE_INFO_FIELDS_PERMISSIONS) != 0) {
+				
+				/* Call this separately from the time one, since one of them may fail,
+				   making the other not run. */
+				gnome_vfs_set_file_info_uri (target_dir_uri, info, 
+							     GNOME_VFS_SET_FILE_INFO_OWNER | 
+							     GNOME_VFS_SET_FILE_INFO_PERMISSIONS);
+			}
 		}
 		
 		/* Call this last so nothing else changes the times */
 		gnome_vfs_set_file_info_uri (target_dir_uri, info, GNOME_VFS_SET_FILE_INFO_TIME);
 		gnome_vfs_file_info_unref (info);
 	}
+	
 	if (target_dir_info) {
 		gnome_vfs_file_info_unref (target_dir_info);
 	}
@@ -2191,6 +2205,7 @@ gnome_vfs_xfer_delete_items (const GList *source_uri_list,
 	 */
 	progress->progress_info->bytes_total
 		= progress->progress_info->files_total * DEFAULT_SIZE_OVERHEAD;
+	progress->progress_info->top_level_item = TRUE;
 	if (result != GNOME_VFS_ERROR_INTERRUPTED) {
 		call_progress (progress, GNOME_VFS_XFER_PHASE_READYTOGO);
 		result = gnome_vfs_xfer_delete_items_common (source_uri_list,
@@ -2502,11 +2517,10 @@ gnome_vfs_xfer_uri_internal (const GList *source_uris,
 		progress->progress_info->total_bytes_copied = 0;
 
 		if (result != GNOME_VFS_OK) {
-			/* don't care about any results from handle_error */
-			handle_error (&result, progress, &error_mode, &skip);
-
-			/* whatever error it was, we handled it */
-			result = GNOME_VFS_OK;
+			if (handle_error (&result, progress, &error_mode, &skip)) {
+				/* whatever error it was, we handled it */
+				result = GNOME_VFS_OK;
+			}
 		} else {
 			call_progress (progress, GNOME_VFS_XFER_PHASE_READYTOGO);
 
@@ -2636,25 +2650,25 @@ _gnome_vfs_xfer_private (const GList *source_uri_list,
 
 /**
  * gnome_vfs_xfer_uri_list:
- * @source_uri_list: A Glist of uris  (ie file;//)
- * @target_uri_list: A GList of uris  
+ * @source_uri_list: a #GList of uris  (ie file://).
+ * @target_uri_list: a #GList of uris.
  * @xfer_options: These are options you wish to set for the transfer. For
  * instance by setting the xfer behavior you can either make a copy or a 
  * move.  
  * @error_mode:  Decide how to behave if the xfer is interrupted.  For instance
  * you could set your application to return an error code in case of an
- * interuption.
- * @overwrite_mode: How to react if a file your copying is being overwritten.
+ * interruption.
+ * @overwrite_mode: How to react if a file is being overwritten.
  * @progress_callback:  This is used to monitor the progress of a transfer.
  * Common use would be to check to see if the transfer is asking for permission
  * to overwrite a file.
- * @data: Data to be want passed back in callbacks from the xfer engine
+ * @data: Data to be passed back in callbacks from the xfer engine.
  *
- * This function will transfer multiple files to a multiple targets.  Given a
- * a source uri(s) and a destination uri(s).   There are a list of options that
+ * This function will transfer multiple files to a multiple targets.  Given
+ * source uri(s) and destination uri(s).   There are a list of options that
  * your application can use to control how the transfer is done.
  *
- * Returns: If all goes well it returns GNOME_VFS_OK.  Check GnomeVFSResult for
+ * Returns: If all goes well it returns %GNOME_VFS_OK.  Check #GnomeVFSResult for
  * other values.
  **/
 GnomeVFSResult
@@ -2711,16 +2725,19 @@ gnome_vfs_xfer_uri_list (const GList *source_uri_list,
  * GNOME_VFS_XFER_RECURSIVE xfer option.
  * GNOME_VFS_XFER_REMOVESOURCE: This option will remove the source data after
  * whatever xfer option has been taken.
- * GNOME_VFS_USE_UNIQUE_NAMES:  This is a check ot make sure that what you copy
+ * GNOME_VFS_USE_UNIQUE_NAMES:  This is a check to make sure that what you copy
  * onto the destination is not overwritten.  It will only copy the unique items
- * from the source to the destjnation.
+ * from the source to the destination.
  * GNOME_VFS_XFER_LINK_ITEMS: <TBA>
+ * GNOME_VFS_XFER_TARGET_DEFAULT_PERMS: This means that the target file will
+ * not have the same permissions as of the source file, but will instead have the 
+ * default permissions of the destination location.
  * @error_mode:  When this function returns you need to check the error code
  * for the results of the copy.  The results are generally:
  * GNOME_VFS_XFER_ERROR_MODE_ABORT: This means that the operation was aborted
  * by some sort of signal that interrupted the transfer.
  * GNOME_VFS_ERROR_MODE_QUERY: This means that no error has occured and that
- * you should query with the GNOME_VFS_XFER_PROGRESS_STATUS_VFSERROR.  See
+ * you should query with the GNOME_VFS_XFER_PROGRESS_STATUS_VFSERROR.
  * @overwrite_mode:  This sets the options to deal with data that are duplicate
  * between the source and the destination.  Your choices are:
  * GNOME_VFS_XFER_OVERWRITE_MODE_ABORT:  This means abort the transfer if you
@@ -2728,19 +2745,16 @@ gnome_vfs_xfer_uri_list (const GList *source_uri_list,
  * GNOME_VFS_XFER_OVERWRITE_MODE_REPLACE: Replace the files silently.  Don't
  * worry be happy.
  * GNOME_VFS_XFER_OVERWRITE_MODE_SKIP: Skip duplicate files silenty.
- * target.
- * @progress_callback:  This is an important call back because this is how you
- * communicate with your copy process.  
- * @data: Data to be want passed back in callbacks from the xfer engine
+ * @progress_callback:  This is an important callback because this is how you
+ * communicate with your transfer process.  
+ * @data: Data to be passed back to callbacks from the xfer engine.
  * 
- * This function will allow a person to copy data from one location to another.
- * The location is specified using a URIs as the means to describe the location
- * of the data.  Like any copy there are several options that can be set.
- * These can be set using the xfer_options.    In addition there are callback
- * mechanisms and error codes to provide feedback in the copy
- * process.
+ * This function will allow a person to transfer data from one location to another.
+ * The locations are specified using URIs. Several options can be set for the operation.
+ * These can be set using the @xfer_options. In addition, there are callback
+ * mechanisms and error codes to provide feedback in the transfer process.
  *
- * Return value: An integer representing the result of the operation.
+ * Return value: an integer representing the result of the operation.
  *
  **/
 GnomeVFSResult	
@@ -2774,15 +2788,15 @@ gnome_vfs_xfer_uri (const GnomeVFSURI *source_uri,
 
 /**
  * gnome_vfs_xfer_delete_list:
- * @source_uri_list:  This is a list containing uris
- * @error_mode:  Decide how you want to deal with interruptions
+ * @source_uri_list: This is a list containing uris.
+ * @error_mode: Decide how you want to deal with interruptions.
  * @xfer_options: Set whatever transfer options you need.
  * @progress_callback: Callback to check on progress of transfer.
- * @data: Data to be want passed back in callbacks from the xfer engine
+ * @data: Data to be passed back in callbacks from the xfer engine.
  *
- * Unlink items in the list @source_uri_list from their filesystems.
+ * Unlinks items in the @source_uri_list from their filesystems.
  *
- * Return value: %GNOME_VFS_OK if successful, or the appropriate error code otherwise
+ * Return value: %GNOME_VFS_OK if successful, or the appropriate error code otherwise.
  **/
 GnomeVFSResult 
 gnome_vfs_xfer_delete_list (const GList *source_uri_list, 
